==> mdview-2023.10-x86_64-1.txz: usr/share/mdview/examples/table_test.md <==
that ### DESCRIPTION

<!--
https://www.markdownguide.org/extended-syntax/#tables
-->
mdview supports tables in a limited way: it can recognize table syntax, and it
displays the table as an unstyled code block.  Therefore, if the original table
text is aligned, the output table will look aligned.

Of course, inside the table block all characteristics of a code block apply, for
instance, `_`, `*`, and `+++` represent themselves, no smart quote replacement,
and so on.

### TESTS

-------------------------------------------------------------------------------

**TEST aligned table...**

| Qty | Food   |
| --- | ------ |
|   1 | mango  |
|  12 | eggs   |

**RESULT** aligned table: "Qty/Food", underlines, "1/mango", "12/eggs"

-------------------------------------------------------------------------------

**TEST aligned table, H3 before...**

# H3
| Qty | Food   |
| --- | ------ |
|   1 | mango  |
|  12 | eggs   |

**RESULT** heading "H3"; aligned table: "Qty/Food", underlines, "1/mango", "12/eggs"

-------------------------------------------------------------------------------

**TEST aligned table, two lines after...**

| Qty | Food   |
| --- | ------ |
|   1 | mango  |
|  12 | eggs   |
line 1
line 2

**RESULT** aligned table: "Qty/Food", underlines, "1/mango", "12/eggs"; paragraph "line 1 line 2"

-------------------------------------------------------------------------------

**TEST minimal table...**

| Qty | Food   |
| --- | ------ |
line 1

**RESULT** aligned table: "Qty/Food**" (with underlines); paragraph "line 1"

-------------------------------------------------------------------------------

**TEST not table 1...**

| Qty | Food   |
line 1

**RESULT** paragraph "| Qty | Food   | line 1" -- underlines are required

-------------------------------------------------------------------------------

**TEST not table 2...**

| Qty | Food   |
| --  | --     |
line 1

**RESULT** paragraph "| Qty | Food   | | —  | —     | line 1" -- at least 3 dashes are required

-------------------------------------------------------------------------------

**TEST alignment markers (understood but ignored)...**

| Qty  | Food   | Life |
| ---: | :----- | :---:|
|   1  | mango  |  5d  |
|  12  | eggs   |  1w  |

**RESULT** aligned table: "Qty/Food/Life", underlines, "1/mango/5d", "12/eggs/1w"

-------------------------------------------------------------------------------

**TEST misaligned table...**

| Qty | Food   |
| --- | --- |
|  1 | mango  |
| 12 | eggs   |

**RESULT** misaligned table: "Qty/Food", underlines, "1/mango", "12/eggs" -- "misaligned is what misaligned does" `:()`

-------------------------------------------------------------------------------

**TEST no left bar ...**

  Qty  | Food   | Life |
  ---: | :----- | :---:|
    1  | mango  |  5d  |
   12  | eggs   |  1w  |

-------------------------------------------------------------------------------

**TEST no right bar ...**

| Qty  | Food   | Life
| ---: | :----- | :---:
|   1  | mango  |  5d  
|  12  | eggs   |  1w  

-------------------------------------------------------------------------------

**TEST no side bars ...**

Qty  | Food   | Life
---  | ------ | ----
  1  | mango  |  5d
 12  | eggs   |  1w

**RESULT** aligned table: "Qty/Food/Life", underlines, "1/mango/5d", "12/eggs/1w"

-------------------------------------------------------------------------------

**TEST formatting is not applied ...**

_Qty_  | **Food**   | +++Life+++
---  | ------ | ----
  `1`  | mango  |  5d
 12  | eggs   |  1w

**RESULT** aligned table (no formatting): "Qty/Food/Life", underlines, "1/mango/5d", "12/eggs/1w"

-------------------------------------------------------------------------------

**TEST table, GFM code block before ...**

```
code block
```
| Qty | Food   |
| --- | ------ |
line 1

**RESULT** two code blocks, paragraph "line 1"

-------------------------------------------------------------------------------

**TEST table, indented code block before, GFM code block after ...**

    <-- 4 Spaces     code block line 1
	<-- Tab          code block line 2
	| there is an empty markdown line below |    code block line 3


| Qty | Food   |
| --- | ------ |
```
code block
```
line 1

**RESULT** three code blocks, paragraph "line 1"  
_Note that in this case an empty line is needed between the indented
code block and the table otherwise the table becomes a_ ***paragraph***,
_which ends the indented code block._

-------------------------------------------------------------------------------

**TEST table, indented code block after ...**

| Qty | Food   |
| --- | ------ |
    <-- 4 Spaces     code block line 1
	<-- Tab          code block line 2
line 1

**RESULT** two code blocks, paragraph "line 1"

-------------------------------------------------------------------------------

### PASS if all RESULT lines above are true

==> mdview-2024.02-x86_64-1.txz: usr/share/mdview/examples/table_test.md <==
that ### DESCRIPTION

<!--
https://www.markdownguide.org/extended-syntax/#tables
-->
mdview supports tables in a limited way: it can recognize table syntax, and it
displays the table as an unstyled code block.  Therefore, if the original table
text is aligned, the output table will look aligned.

Inside the table block all characteristics of a code block apply. For instance,
`_`, `*`, and `+++` represent themselves; quotes don't become smart quotes, and
so on.

### TESTS

-------------------------------------------------------------------------------

**TEST aligned table...**

| Qty | Food   |
| --- | ------ |
|   1 | mango  |
|  12 | eggs   |

**RESULT** aligned table: "Qty/Food", underlines, "1/mango", "12/eggs"

-------------------------------------------------------------------------------

**TEST aligned table, H3 before...**

# H3
| Qty | Food   |
| --- | ------ |
|   1 | mango  |
|  12 | eggs   |

**RESULT** heading "H3"; aligned table: "Qty/Food", underlines, "1/mango", "12/eggs"

-------------------------------------------------------------------------------

**TEST aligned table, two lines after...**

| Qty | Food   |
| --- | ------ |
|   1 | mango  |
|  12 | eggs   |
line 1
line 2

**RESULT** aligned table: "Qty/Food", underlines, "1/mango", "12/eggs"; paragraph "line 1 line 2"

-------------------------------------------------------------------------------

**TEST minimal table...**

| Qty | Food   |
| --- | ------ |
line 1

**RESULT** aligned table: "Qty/Food" (with underlines); paragraph "line 1"

-------------------------------------------------------------------------------

**TEST not table 1...**

| Qty | Food   |
line 1

**RESULT** paragraph "| Qty | Food   | line 1" -- underlines are required

-------------------------------------------------------------------------------

**TEST not table 2...**

| Qty | Food   |
| --  | --     |
line 1

**RESULT** paragraph "| Qty | Food   | | —  | —     | line 1" -- at least 3 dashes are required

-------------------------------------------------------------------------------

**TEST alignment markers (understood but ignored)...**

| Qty  | Food   | Life |
| ---: | :----- | :---:|
|   1  | mango  |  5d  |
|  12  | eggs   |  1w  |

**RESULT** aligned table: "Qty/Food/Life", underlines, "1/mango/5d", "12/eggs/1w"

-------------------------------------------------------------------------------

**TEST misaligned table...**

| Qty | Food   |
| --- | --- |
|  1 | mango  |
| 12 | eggs   |

**RESULT** misaligned table: "Qty/Food", underlines, "1/mango", "12/eggs" -- "misaligned is what misaligned does" `:()`

-------------------------------------------------------------------------------

**TEST no left bar ...**

  Qty  | Food   | Life |
  ---: | :----- | :---:|
    1  | mango  |  5d  |
   12  | eggs   |  1w  |

-------------------------------------------------------------------------------

**TEST no right bar ... (and two trailing spaces)**

| Qty  | Food   | Life
| ---: | :----- | :---:
|   1  | mango  |  5d  
|  12  | eggs   |  1w  

-------------------------------------------------------------------------------

**TEST no side bars ...**

Qty  | Food   | Life
---  | ------ | ----
  1  | mango  |  5d
 12  | eggs   |  1w

**RESULT** aligned table: "Qty/Food/Life", underlines, "1/mango/5d", "12/eggs/1w"

-------------------------------------------------------------------------------

**TEST formatting is not applied ...**

_Qty_ | **Food** | +++Life+++
---   | ------   | ----
  `1` | mango    | 5d
 *2*  | eggs     | 1w
 _1_  | milk     | 3d
 "1"  | rope     | --

**RESULT** aligned table (no formatting): "Qty/Food/Life", underlines, "1/mango/5d", "12/eggs/1w"

-------------------------------------------------------------------------------

**TEST table, fenced code block before ...**

```
code block
```
| Qty | Food   |
| --- | ------ |
line 1

**RESULT** two code blocks, paragraph "line 1"

-------------------------------------------------------------------------------

**TEST table, indented code block before, fenced code block after ...**

    <-- 4 Spaces     code block line 1
	<-- Tab          code block line 2
	| there is an empty markdown line below |    code block line 3


| Qty | Food   |
| --- | ------ |
```
code block
```
line 1

**RESULT** three code blocks, paragraph "line 1"  
_Note that in this case an empty line is needed between the indented
code block and the table otherwise the table becomes a_ ***paragraph***,
_which ends the indented code block._

-------------------------------------------------------------------------------

**TEST table, indented code block after ...**

| Qty | Food   |
| --- | ------ |
    <-- 4 Spaces     code block line 1
	<-- Tab          code block line 2
line 1

**RESULT** two code blocks, paragraph "line 1"

-------------------------------------------------------------------------------

### PASS if all RESULT lines above are true
